# Make Spatial Hurdle.r
# Simulated NB Spatial Hurdle Data 
# Outfile: ~/spatialhurdledata.txt
# October 27, 2012
####################################
library(mvtnorm)
source("E:/Negative Binomial Regression in WinBUGS/Makedata/writeDatafileR.txt") 

 set.seed(102712)
 n<-100			# Number of blocks
 nis<-rep(25,n) 	# Number of individuals per block; here it's balanced  
 id<-rep(1:n,nis)		
 N<-length(id) 		# Total number of subjects

########################
#  Make Spatial Effect #
########################
# Generate symmetric adjaceny matrix, A  
  A<-matrix(0,n,n)
  A[upper.tri(A,diag=F)]<-rbinom(n*(n-1)/2,1,.1)
  A<-A+t(A) 
  m<-apply(A,1,sum)	# Num. neighbors
  adjid<-rep(1:n,m)	# Tells which elements of A belong to which block

  adj<-rep(0,sum(m))
  for (i in 1:n)adj[adjid==i]<-which(A[i,]==1)  
  
# Spatial effects, phi
 rho<-.9999				# Spatial dependence parameter ~ 1 for intrinsic CAR
 cov<-matrix(c(4,4,4,16),2,2)   	# conditional Cov of phi1 and phi2 given phi_{-i} 
 Q<-diag(m)-rho*A			# NOTE: Indt random effects ==>  rho=0 & m=1 for all i
 
 covphi<-solve(Q)%x%cov			# 2n x 2n covariance of phis
 phi<-rmvnorm(1,sigma=covphi)		# 2n vector of spatial effects
 Phitmp<-matrix(phi,ncol=2,byrow=T) 	# n x 2 matrix of spatial effects
 phi1<-rep(Phitmp[,1]-mean(Phitmp[,1]),nis) # N x 1 phi1 vector -- Centered
 phi2<-rep(Phitmp[,2]-mean(Phitmp[,2]),nis) # N x 1 phi2 vector 
 Phi<-cbind(Phitmp[,1]-mean(Phitmp[,1]),Phitmp[,2]-mean(Phitmp[,2]))

#############################
#  Make Hurdle Outcome Given#
#	Spatial Effects     #
#############################
 x<-sample(0:4,N,replace=T)	# Fixed effect covariate
 X<-cbind(1,x)			# Design Matrix
 alpha<-c(-1,1)			# Fixed effect reg parms for logistic component
 eta1<-X%*%alpha+phi1
 p<-exp(eta1)/(1+exp(eta1))   # 1 - Prob of Zero
 z<-rbinom(N,1,p)

 beta<-c(2,-1)			# Fixed effect reg parms for NB component
 eta2<-X%*%beta+phi2
 mu<-exp(eta2)

  rtnb <- function(n=n,mu=mu,r=r){
     qnbinom(runif(n, dnbinom(0, size=r,mu=mu), 1), size=r,mu=mu)  # Truncated Negative Binomial Distribution
 }
 y<-rtnb(n=N,r=10,mu=mu)   	# Scale = 10

 y[z==0]<-0

####################
# Write to WinBUGS #
####################
data<-list(id=id,y=c(y),x=x,N=c(N),n=n,M=sum(m),Omega=diag(2),nu=3,m=m,adj=adj)
  
writeDatafileR(data,"E:/Negative Binomial Regression in WinBUGS/data/spatialhurdledata.txt")  # Export to WinBUGS

