# Computes Posterior Means and Trace Plots for NB Hurdle Model
# Infiles:1) Data = E:/Negative Binomial Regression in WinBUGS/R2WinBUGS/Data/spatialhurdledata.txt
# 		    2) Posterior Samples = E:/Negative Binomial Regression in WinBUGS/R2WinBUGS/Coda/results.txt
# Oct 29, 2012
###########################
library(R2WinBUGS)

########
# Data #
########
 data<-dget("E:/Brian/Negative Binomial Regression in WinBUGS/R2WinBUGS/Data/spatialhurdledata.txt")
 n<-data$n

##############
# Coda Files #
##############
 setwd("E:/Brian/Negative Binomial Regression in WinBUGS/R2WinBUGS/coda/")
 coda<-read.coda("coda1.txt","codaIndex.txt",quiet=T)
 
 Phi1<-coda[,1:n]
 Phi2<-coda[,(n+1):(2*n)]
 Sigma.phi<-coda[,(2*n+1):(2*n+4)]
 Alpha<-coda[,(2*n+5):(2*n+6)]  # Fixed effects for binomial part of hurdle model
 Beta<-coda[,(2*n+7):(2*n+8)]   # Fixed effects for count part
 R<-coda[,ncol(coda)]           # Neg. Binomial Scale Parameter

###################
# Posterior Means #
###################
 ahat<-colMeans(Alpha)	   # True alpha = c(-1,1)
 bhat<-colMeans(Beta) 	   # True beta = c(2,-1)
 Sphi<-colMeans(Sigma.phi) 	# True Sigphi = c(4,4,4,16)
 CISphi<-t(apply(Sigma.phi,2,quantile,prob=c(0.025,0.975))) # 95% Cred. Interval
 rhat<-mean(R)                 	# True value = 10
 cir<-quantile(R,prob=c(0.025,0.975))

#############################
# Traceplot for beta2 and r #
#############################
 traceplot(mcmc.list(Beta[,2]),col="lightgreen",main="Traceplot of Beta_2",
                  ylab=expression(beta[2]))
 abline(h=bhat[2],col="blue4")

 traceplot(mcmc.list(R),col="lightgreen",main="Traceplot of Rho",ylab=expression(rho))
 abline(h=rhat,col="blue4")
